module Qunar
  class Hotel
    BASEURI = "http://hotel.qunar.com"
    def initialize(hotelId)
      #super
      raise "id should be string" if !hotelId.instance_of?(String)
      @HotelSEQ = hotelId             #hotelId is "cityurl_hotelcode"
      @cityurl = hotelId[0..hotelId.rindex("_",-1)-1]
      @hotelcode = hotelId[hotelId.rindex("_",-1)+1..hotelId.length]
      uri = URI(File.join(BASEURI, 'city', @cityurl, "dt-#{@hotelcode}"))
      page = HTTParty.get(uri.to_s)
      @hotel = Nokogiri::HTML page
    end

    def name          #get the name of the hotel
      name  = @hotel.search("//div[@class='htl-info fr']//span")
      if name.empty?
        name = '该酒店不存在'
      else
        name = name.first.text.strip
      end
      return name
    end

    def star         #get the level of the hotel
      name_tag = @hotel.search('//div[@class="htl-info fr"]//em[@class="dangci"]').first
      return 0 if name_tag.nil?
      if name_tag.text.include?'经济型'
        1
      elsif name_tag.text.include?'舒适型'
        3
      elsif name_tag.text.include?'高档型'
        4
      elsif name_tag.text.include?'豪华型'
        5
      elsif name_tag.text.include?'star20'
        2
      elsif name_tag.text.include?'star50'
        5
      else
        0
      end
    end

    def citynameEn
      @cityurl.sub('_city','')
    end

    def citynameCn
      match_data = @hotel.to_s.match(/var\s*cityName\s*=\s*\'\p{Han}+\'/u)
      return "" if match_data.nil?
      match_data = match_data[0].match(/\p{Han}+/u)
      return "" if match_data.nil?
      match_data[0].strip
    end

    def id
      @hotelcode = @hotelcode.to_i
    end

    def address
      @hotel.search("//p[@class='adress']/span").first['title'].strip
      #return "" if address.nil?
      #return address['title'].strip
    end

    def phone
      @hotel.search("//dl[@class='inform-list']//cite").first.text.sub('电话','').strip
    end

    #the description of the hotel
    def desc
      @hotel.search("div[@class='introduce']/p").text
    end

    #开业时间
    def opentime
      #date ||= @hotel.search("p[@class='insttime']/cite").text.sub("开业时间：","")
      #date.strip
      @hotel.search("dl[@class='inform-list']//cite")[-2].text.sub("年开业",'')
    end

    def reference_price
      match_data = @hotel.to_s.match(/var\s*miniRetailPrice\s*=\s*\'\d+\';/)
      return 0 if match_data.nil?
      match_data = match_data[0].match(/[\d]+/)
      return 0 if match_data.nil?
      match_data[0].strip.to_i
    end

    def coordinate
      xy = @hotel.to_s.match(/hotelPoint=\[(\d+\.\d+),(\d+\.\d+)\];/)
      if xy.nil?
        return [0.0,0.0]
      else
        return [xy[1],xy[2]]
      end
    end

  end
end
